"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCalendarGrid = exports.CalendarGrid = void 0;

var _react = require("react");

var _reakit = require("reakit");

var _reakitUtils = require("reakit-utils");

var _utils = require("@chakra-ui/utils");

var _utils2 = require("@react-aria/utils");

var _system = require("../system");

var _utils3 = require("../utils");

var _keys = require("./__keys");

var _excluded = ["ref", "onKeyDown", "onBlur", "onBlur"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var useCalendarGrid = (0, _system.createHook)({
  name: "CalendarGrid",
  compose: _reakit.useRole,
  keys: _keys.CALENDAR_GRID_KEYS,
  useProps: function useProps(options, _ref) {
    var htmlRef = _ref.ref,
        htmlOnKeyDown = _ref.onKeyDown,
        htmlOnFocus = _ref.onBlur,
        htmlOnBlur = _ref.onBlur,
        htmlProps = _objectWithoutProperties(_ref, _excluded);

    var isReadOnly = options.isReadOnly,
        isDisabled = options.isDisabled,
        setFocused = options.setFocused,
        selectFocusedDate = options.selectFocusedDate,
        focusPreviousYear = options.focusPreviousYear,
        focusPreviousMonth = options.focusPreviousMonth,
        focusNextYear = options.focusNextYear,
        focusNextMonth = options.focusNextMonth,
        focusEndOfMonth = options.focusEndOfMonth,
        focusStartOfMonth = options.focusStartOfMonth,
        focusNextDay = options.focusNextDay,
        focusPreviousDay = options.focusPreviousDay,
        focusNextWeek = options.focusNextWeek,
        focusPreviousWeek = options.focusPreviousWeek,
        calendarId = options.calendarId,
        setAnchorDate = options.setAnchorDate;
    var ref = (0, _react.useRef)(null);
    var onKeyDown = (0, _reakitUtils.createOnKeyDown)({
      onKeyDown: htmlOnKeyDown,
      preventDefault: true,
      keyMap: function keyMap(event) {
        var shift = event.shiftKey;
        return {
          " ": selectFocusedDate,
          Enter: selectFocusedDate,
          End: focusEndOfMonth,
          Home: focusStartOfMonth,
          ArrowLeft: focusPreviousDay,
          ArrowUp: focusPreviousWeek,
          ArrowRight: focusNextDay,
          ArrowDown: focusNextWeek,
          PageUp: function PageUp() {
            shift ? focusPreviousYear() : focusPreviousMonth();
          },
          PageDown: function PageDown() {
            shift ? focusNextYear() : focusNextMonth();
          }
        };
      }
    });
    var rangeCalendarProps = {};

    if (options.isRangeCalendar) {
      var onRangeKeyDown = function onRangeKeyDown(e) {
        switch (e.key) {
          case "Escape":
            // Cancel the selection.
            setAnchorDate === null || setAnchorDate === void 0 ? void 0 : setAnchorDate(null);
            break;
        }
      };

      rangeCalendarProps = {
        "aria-multiselectable": true,
        onKeyDown: (0, _utils.callAllHandlers)(htmlOnKeyDown, (0, _utils2.chain)(onKeyDown, onRangeKeyDown))
      };
    }

    return _objectSpread(_objectSpread({
      ref: (0, _reakitUtils.useForkRef)(ref, htmlRef),
      role: "grid",
      "aria-labelledby": calendarId,
      "aria-readonly": (0, _utils3.ariaAttr)(isReadOnly),
      "aria-disabled": (0, _utils3.ariaAttr)(isDisabled),
      onKeyDown: (0, _utils.callAllHandlers)(htmlOnKeyDown, onKeyDown),
      onFocus: (0, _utils.callAllHandlers)(htmlOnFocus, function () {
        return setFocused(true);
      }),
      onBlur: (0, _utils.callAllHandlers)(htmlOnBlur, function () {
        return setFocused(false);
      })
    }, rangeCalendarProps), htmlProps);
  }
});
exports.useCalendarGrid = useCalendarGrid;
var CalendarGrid = (0, _system.createComponent)({
  as: "div",
  memo: true,
  useHook: useCalendarGrid
});
exports.CalendarGrid = CalendarGrid;
//# sourceMappingURL=CalendarGrid.js.map