"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  useWeekDays: true,
  generateDaysInMonthArray: true,
  makeRange: true
};
exports.generateDaysInMonthArray = generateDaysInMonthArray;
exports.makeRange = makeRange;
exports.useWeekDays = useWeekDays;

var _i18n = require("@react-aria/i18n");

var _utils = require("../../utils");

var _useWeekStart = require("./useWeekStart");

Object.keys(_useWeekStart).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _useWeekStart[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _useWeekStart[key];
    }
  });
});

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function useWeekDays(weekStart) {
  var dayFormatter = (0, _i18n.useDateFormatter)({
    weekday: "short"
  });
  var dayFormatterLong = (0, _i18n.useDateFormatter)({
    weekday: "long"
  });
  return [0, 1, 2, 3, 4, 5, 6].map(function (index) {
    var dateDay = (0, _utils.setDay)(Date.now(), (index + weekStart) % 7);
    var day = dayFormatter.format(dateDay);
    var dayLong = dayFormatterLong.format(dateDay);
    return {
      title: dayLong,
      abbr: day
    };
  });
}

function generateDaysInMonthArray(month, monthStartsAt, weeksInMonth, year) {
  return Array(weeksInMonth).fill(1).reduce(function (weeks, _, weekIndex) {
    var daysInWeek = [0, 1, 2, 3, 4, 5, 6].reduce(function (days, dayIndex) {
      var day = weekIndex * 7 + dayIndex - monthStartsAt + 2;
      var utcDate = (0, _utils.toUTCString)(new Date(year, month, day));
      var cellDate = new Date(utcDate);
      return [].concat(_toConsumableArray(days), [cellDate]);
    }, []);
    return [].concat(_toConsumableArray(weeks), [daysInWeek]);
  }, []);
}

function makeRange(start, end) {
  if (end < start) {
    var _ref = [end, start];
    start = _ref[0];
    end = _ref[1];
  }

  return {
    start: start,
    end: end
  };
}
//# sourceMappingURL=index.js.map