"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useMeter = exports.Meter = void 0;

var _reakitSystem = require("reakit-system");

var _reakit = require("reakit");

var _reakitWarning = require("reakit-warning");

var _keys = require("./__keys");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var useMeter = (0, _reakitSystem.createHook)({
  name: "Meter",
  compose: _reakit.useRole,
  keys: _keys.METER_KEYS,
  useProps: function useProps(options, htmlProps) {
    var value = options.value,
        max = options.max,
        min = options.min,
        percent = options.percent; // Use the meter role if available, but fall back to progressbar if not
    // Chrome currently falls back from meter automatically, and Firefox
    // does not support meter at all. Safari 13+ seems to support meter properly.
    // https://bugs.chromium.org/p/chromium/issues/detail?id=944542
    // https://bugzilla.mozilla.org/show_bug.cgi?id=1460378
    // @see https://github.com/adobe/react-spectrum/blob/main/packages/%40react-aria/meter/src/useMeter.ts

    return _objectSpread({
      role: "meter progressbar",
      "aria-valuemax": max,
      "aria-valuemin": min,
      "aria-valuenow": value,
      "aria-valuetext": !percent.toString() ? undefined : "".concat(percent, "%")
    }, htmlProps);
  }
});
exports.useMeter = useMeter;
var Meter = (0, _reakitSystem.createComponent)({
  as: "div",
  memo: true,
  useHook: useMeter,
  useCreateElement: function useCreateElement(type, props, children) {
    (0, _reakitWarning.useWarning)(!props["aria-label"] && !props["aria-labelledby"], "You should provide either `aria-label` or `aria-labelledby` props.", "See https://w3c.github.io/aria-practices/#wai-aria-roles-states-and-properties-15");
    return (0, _reakitSystem.useCreateElement)(type, props, children);
  }
});
exports.Meter = Meter;
//# sourceMappingURL=Meter.js.map