"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useNumberInputState = useNumberInputState;

var React = _interopRequireWildcard(require("react"));

var _counter = require("@chakra-ui/counter");

var _hooks = require("@chakra-ui/hooks");

var _utils = require("@chakra-ui/utils");

var _helpers = require("./helpers");

var _excluded = ["update", "cast", "clamp", "increment", "decrement"];

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function useNumberInputState() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var _props$min = props.min,
      min = _props$min === void 0 ? _utils.minSafeInteger : _props$min,
      _props$max = props.max,
      max = _props$max === void 0 ? _utils.maxSafeInteger : _props$max,
      _props$step = props.step,
      stepProp = _props$step === void 0 ? 1 : _props$step,
      _props$keepWithinRang = props.keepWithinRange,
      keepWithinRange = _props$keepWithinRang === void 0 ? true : _props$keepWithinRang,
      _props$focusInputOnCh = props.focusInputOnChange,
      focusInputOnChange = _props$focusInputOnCh === void 0 ? true : _props$focusInputOnCh,
      isReadOnly = props.isReadOnly,
      isDisabled = props.isDisabled,
      isInvalid = props.isInvalid,
      isRequired = props.isRequired;
  /**
   * Leverage the `useCounter` hook since it provides
   * the functionality to `increment`, `decrement` and `update`
   * counter values
   */

  var counter = (0, _counter.useCounter)(props);

  var updateValue = counter.update,
      setCastedValue = counter.cast,
      clampToPrecision = counter.clamp,
      incrementFn = counter.increment,
      decrementFn = counter.decrement,
      counterProps = _objectWithoutProperties(counter, _excluded);

  var isInteractive = !(isReadOnly || isDisabled);
  var increment = React.useCallback(function () {
    var step = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : stepProp;

    if (isInteractive) {
      incrementFn(step);
    }
  }, [incrementFn, isInteractive, stepProp]);
  var decrement = React.useCallback(function () {
    var step = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : stepProp;

    if (isInteractive) {
      decrementFn(step);
    }
  }, [decrementFn, isInteractive, stepProp]);
  /**
   * Leverage the `useSpinner` hook to spin the input's value
   * when long press on the up and down buttons.
   *
   * This leverages `setInterval` internally
   */

  var spinner = (0, _helpers.useSpinner)(increment, decrement);
  var inputRef = React.useRef(null);
  /**
   * Sync state with uncontrolled form libraries like `react-hook-form`.
   */

  (0, _hooks.useSafeLayoutEffect)(function () {
    if (!inputRef.current) return;
    var notInSync = inputRef.current.value !== counter.value;

    if (notInSync) {
      counter.setValue((0, _helpers.sanitize)(inputRef.current.value));
    }
  }, [counter.value]);
  var focusInput = React.useCallback(function () {
    if (focusInputOnChange && inputRef.current) {
      (0, _utils.focus)(inputRef.current, {
        nextTick: true
      });
    }
  }, [focusInputOnChange]);
  return _objectSpread(_objectSpread({
    min: min,
    max: max,
    step: stepProp,
    keepWithinRange: keepWithinRange,
    updateValue: updateValue,
    setCastedValue: setCastedValue,
    clampToPrecision: clampToPrecision,
    increment: increment,
    decrement: decrement
  }, counterProps), {}, {
    inputRef: inputRef,
    focusInput: focusInput,
    spinUp: spinner.up,
    spinDown: spinner.down,
    spinStop: spinner.stop,
    isReadOnly: isReadOnly,
    isDisabled: isDisabled,
    isInvalid: isInvalid,
    isRequired: isRequired
  });
}
//# sourceMappingURL=NumberInputState.js.map