"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTypeaheadShortcut = useTypeaheadShortcut;

var _react = _interopRequireDefault(require("react"));

var _reakitUtils = require("reakit-utils");

var _hooks = require("@chakra-ui/hooks");

var _utils = require("@chakra-ui/utils");

var _SelectBaseState = require("../SelectBaseState");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Reference:
// https://github.com/reakit/reakit/blob/01e73eaff9405ecf8838906684811ef70970b867/packages/reakit/src/Menu/__utils/useShortcuts.ts
function useTypeaheadShortcut(_ref) {
  var ref = _ref.ref,
      options = _ref.options,
      timeout = _ref.timeout;
  var onCharacterPress = (0, _hooks.useShortcut)({
    preventDefault: function preventDefault(event) {
      return event.key !== " ";
    },
    timeout: timeout
  });

  _react.default.useEffect(function () {
    var element = ref.current;
    if (!element) return undefined;

    var onKeyDown = function onKeyDown(event) {
      var _target$getAttribute;

      var target = event.target;
      var role = (_target$getAttribute = target.getAttribute) === null || _target$getAttribute === void 0 ? void 0 : _target$getAttribute.call(target, "role");
      var targetIsDialog = target === element;
      var targetIsOption = role && role.indexOf("option") !== -1 || (0, _reakitUtils.closest)(target, "[role=listbox]") === element;
      if (!targetIsDialog && !targetIsOption) return; // @ts-ignore

      onCharacterPress(handleCharacterPress(options))(event);
    }; // https://github.com/facebook/react/issues/11387#issuecomment-524113945


    element.addEventListener("keydown", onKeyDown);
    return function () {
      return element.removeEventListener("keydown", onKeyDown);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [onCharacterPress]);
}

var handleCharacterPress = function handleCharacterPress(options) {
  return function (character) {
    var selectedValue = options.values.find(function (value) {
      var _options$currentValue;

      return (_options$currentValue = options.currentValue) === null || _options$currentValue === void 0 ? void 0 : _options$currentValue.includes(value);
    });
    var nextItem = (0, _utils.getNextItemFromSearch)(options.values, character, function (item) {
      return item !== null && item !== void 0 ? item : "";
    }, selectedValue);

    if (nextItem) {
      var _options$move;

      var nextId = (0, _SelectBaseState.getIdFromValue)(options.valuesById, nextItem);
      (_options$move = options.move) === null || _options$move === void 0 ? void 0 : _options$move.call(options, nextId);
    }
  };
};
//# sourceMappingURL=useTypeaheadShortcut.js.map