"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LiveRegionAnnouncer = void 0;
exports.announce = announce;
exports.clearAnnouncer = clearAnnouncer;
exports.destroyAnnouncer = destroyAnnouncer;

var _react = _interopRequireWildcard(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _reakit = require("reakit");

var _jsxRuntime = require("react/jsx-runtime");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/* Inspired by https://github.com/AlmeroSteyn/react-aria-live */
var liveRegionAnnouncer = /*#__PURE__*/_react.default.createRef();

var node = null;
var clearTimeoutId = null;
var LIVEREGION_TIMEOUT_DELAY = 1000;

/**
 * Announces the message using screen reader technology.
 */
function announce(message) {
  var assertiveness = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "assertive";
  var timeout = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : LIVEREGION_TIMEOUT_DELAY;
  ensureInstance(function (announcer) {
    return announcer.announce(message, assertiveness, timeout);
  });
}
/**
 * Stops all queued announcements.
 */


function clearAnnouncer(assertiveness) {
  ensureInstance(function (announcer) {
    return announcer.clear(assertiveness);
  });
}
/**
 * Removes the announcer from the DOM.
 */


function destroyAnnouncer() {
  if (liveRegionAnnouncer.current) {
    _reactDom.default.unmountComponentAtNode(node);

    document.body.removeChild(node);
    node = null;
  }
}
/**
 * Ensures we only have one instance of the announcer so that we don't have elements competing.
 */


function ensureInstance(callback) {
  if (!liveRegionAnnouncer.current) {
    node = document.createElement("div");
    document.body.appendChild(node);

    _reactDom.default.render( /*#__PURE__*/(0, _jsxRuntime.jsx)(LiveRegionAnnouncer, {
      ref: liveRegionAnnouncer
    }), node, function () {
      return callback(liveRegionAnnouncer.current);
    });
  } else {
    callback(liveRegionAnnouncer.current);
  }
}

var LiveRegionAnnouncer = /*#__PURE__*/_react.default.forwardRef(function (props, ref) {
  var _useState = (0, _react.useState)(""),
      _useState2 = _slicedToArray(_useState, 2),
      assertiveMessage = _useState2[0],
      setAssertiveMessage = _useState2[1];

  var _useState3 = (0, _react.useState)(""),
      _useState4 = _slicedToArray(_useState3, 2),
      politeMessage = _useState4[0],
      setPoliteMessage = _useState4[1];

  var clear = function clear(assertiveness) {
    if (!assertiveness || assertiveness === "assertive") {
      setAssertiveMessage("");
    }

    if (!assertiveness || assertiveness === "polite") {
      setPoliteMessage("");
    }
  };

  var announce = function announce(message) {
    var assertiveness = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "assertive";
    var timeout = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : LIVEREGION_TIMEOUT_DELAY;

    if (clearTimeoutId) {
      clearTimeout(clearTimeoutId);
      clearTimeoutId = null;
    }

    if (assertiveness === "assertive") {
      setAssertiveMessage(message);
    } else {
      setPoliteMessage(message);
    }

    if (message !== "") {
      clearTimeoutId = setTimeout(function () {
        clear(assertiveness);
      }, timeout);
    }
  };

  (0, _react.useImperativeHandle)(ref, function () {
    return {
      announce: announce,
      clear: clear
    };
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_react.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(MessageAlternator, {
      "aria-live": "assertive",
      message: assertiveMessage
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(MessageAlternator, {
      "aria-live": "polite",
      message: politeMessage
    })]
  });
});

exports.LiveRegionAnnouncer = LiveRegionAnnouncer;

function MessageAlternator(_ref) {
  var _ref$message = _ref.message,
      message = _ref$message === void 0 ? "" : _ref$message,
      ariaLive = _ref["aria-live"];
  var messagesRef = (0, _react.useRef)(["", ""]);
  var indexRef = (0, _react.useRef)(0);

  if (message !== messagesRef.current[indexRef.current]) {
    messagesRef.current[indexRef.current] = "";
    indexRef.current = (indexRef.current + 1) % 2;
    messagesRef.current[indexRef.current] = message;
  }

  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_react.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(MessageBlock, {
      "aria-live": ariaLive,
      message: messagesRef.current[0]
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(MessageBlock, {
      "aria-live": ariaLive,
      message: messagesRef.current[1]
    })]
  });
}

function MessageBlock(_ref2) {
  var _ref2$message = _ref2.message,
      message = _ref2$message === void 0 ? "" : _ref2$message,
      ariaLive = _ref2["aria-live"];
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reakit.VisuallyHidden, {
    "aria-live": ariaLive,
    "aria-relevant": "additions",
    "aria-atomic": "true",
    children: message
  });
}
//# sourceMappingURL=LiveAnnouncer.js.map