function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * All credit goes to [React Spectrum](https://github.com/adobe/react-spectrum)
 * We improved the Calendar from Stately [useDatePickerState](https://github.com/adobe/react-spectrum/blob/main/packages/%40react-stately/datepicker/src/useDatePickerState.ts)
 * to work with Reakit System
 */
import * as React from "react";
import { unstable_useId as useId, useCompositeState } from "reakit";
import { useRangeCalendarState } from "../calendar";
import { makeRange } from "../calendar/helpers";
import { usePickerBaseState } from "../picker-base";
import { useSegmentState } from "../segment";
import { addDays, toUTCRangeString, toUTCString, useControllableState } from "../utils";
export var useDateRangePickerState = function useDateRangePickerState() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var {
    value: initialValue,
    defaultValue = {
      start: toUTCString(new Date()),
      end: toUTCString(addDays(new Date(), 1))
    },
    onChange,
    minValue,
    maxValue,
    isRequired,
    autoFocus,
    formatOptions,
    placeholderDate
  } = props;
  var [value, setValue] = useControllableState({
    value: initialValue,
    defaultValue,
    onChange
  });
  var dateRange = React.useMemo(() => ({
    start: new Date(value.start),
    end: new Date(value.end)
  }), [value.end, value.start]);
  var minDateValue = minValue ? new Date(minValue) : new Date(-864e13);
  var maxDateValue = maxValue ? new Date(maxValue) : new Date(864e13);

  var selectDate = date => {
    if (props.isReadOnly || props.isDisabled) {
      return;
    }

    setValue(toUTCRangeString(makeRange(new Date(date.start), new Date(date.end))));
    popover.hide();
  };

  var segmentComposite = useCompositeState({
    orientation: "horizontal"
  });
  var startSegmentState = useSegmentState({
    value: dateRange.start,
    defaultValue: new Date(defaultValue.start),
    onChange: date => setValue(toUTCRangeString({
      start: date,
      end: dateRange.end
    })),
    formatOptions,
    placeholderDate
  });
  var endSegmentState = useSegmentState({
    value: dateRange.end,
    defaultValue: new Date(defaultValue.end),
    onChange: date => setValue(toUTCRangeString({
      start: dateRange.start,
      end: date
    })),
    formatOptions,
    placeholderDate
  });
  var popover = usePickerBaseState(_objectSpread({
    segmentFocus: segmentComposite.first
  }, props));
  var calendar = useRangeCalendarState({
    value: {
      start: value.start,
      end: value.end
    },
    onChange: selectDate,
    minValue: minValue,
    maxValue: maxValue
  });

  function isInvalidDateRange(value) {
    var min = new Date(minDateValue);
    var max = new Date(maxDateValue);
    return value < min || value > max;
  }

  var isStartInRange = isInvalidDateRange(dateRange.start);
  var isEndInRange = isInvalidDateRange(dateRange.end);
  var validationState = props.validationState || (value != null && (isStartInRange || isEndInRange || value.end != null && value.start != null && value.end < value.start) ? "invalid" : "valid");
  React.useEffect(() => {
    if (popover.visible) {
      calendar.setFocused(true);
      value.start && calendar.focusCell(new Date(value.start));
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [popover.visible]);
  React.useEffect(() => {
    if (autoFocus) {
      segmentComposite.first();
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [autoFocus, segmentComposite.first]);
  var {
    id: startId
  } = useId({
    baseId: "startsegment"
  });
  var {
    id: endId
  } = useId({
    baseId: "endsegment"
  });
  return _objectSpread(_objectSpread({
    dateValue: value,
    setDateValue: setValue,
    selectDate,
    validationState,
    minValue,
    maxValue,
    isRequired
  }, popover), {}, {
    startSegmentState: _objectSpread(_objectSpread(_objectSpread({}, startSegmentState), segmentComposite), {}, {
      baseId: startId
    }),
    endSegmentState: _objectSpread(_objectSpread(_objectSpread({}, endSegmentState), segmentComposite), {}, {
      baseId: endId
    }),
    calendar,
    isDateRangePicker: true
  });
};
//# sourceMappingURL=DateRangePickerState.js.map