var _excluded = ["modal", "hideOnEsc", "hideOnClickOutside", "preventBodyScroll", "unstable_autoFocusOnShow", "unstable_autoFocusOnHide", "unstable_orphan"],
    _excluded2 = ["ref", "onKeyDown", "onBlur", "wrapElement", "tabIndex"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import * as React from "react";
import { RemoveScroll } from "react-remove-scroll";
import { createComponent, createHook, useCreateElement as _useCreateElement } from "reakit-system";
import { Portal } from "reakit";
import { useForkRef, useLiveRef } from "reakit-utils";
import { useWarning, warning } from "reakit-warning";
import { useDisclosureContent } from "../disclosure";
import { DIALOG_KEYS } from "./__keys";
import { DialogBackdropContext, useDisableHoverOutside, useDisclosureRef, useFocusOnBlur, useFocusOnChildUnmount, useFocusOnHide, useFocusOnShow, useFocusTrap, useHideOnClickOutside, useNestedDialogs } from "./helpers";
import { jsx as _jsx } from "react/jsx-runtime";
export var useDialog = createHook({
  name: "Dialog",
  compose: useDisclosureContent,
  keys: DIALOG_KEYS,

  useOptions(options) {
    var {
      modal = true,
      hideOnEsc = true,
      hideOnClickOutside = true,
      preventBodyScroll = modal,
      unstable_autoFocusOnShow = true,
      unstable_autoFocusOnHide = true,
      unstable_orphan
    } = options,
        restOptions = _objectWithoutProperties(options, _excluded);

    return _objectSpread({
      modal,
      hideOnEsc,
      hideOnClickOutside,
      preventBodyScroll: modal && preventBodyScroll,
      unstable_autoFocusOnShow,
      unstable_autoFocusOnHide,
      unstable_orphan: modal && unstable_orphan
    }, restOptions);
  },

  useProps(options, htmlProps) {
    var {
      preventBodyScroll,
      baseId,
      hideOnEsc,
      hide,
      modal: optionsModal
    } = options;

    var {
      ref: htmlRef,
      onKeyDown: htmlOnKeyDown,
      onBlur: htmlOnBlur,
      wrapElement: htmlWrapElement,
      tabIndex
    } = htmlProps,
        restHtmlProps = _objectWithoutProperties(htmlProps, _excluded2);

    var dialog = React.useRef(null);
    var backdrop = React.useContext(DialogBackdropContext);
    var hasBackdrop = backdrop && backdrop === baseId;
    var disclosure = useDisclosureRef(dialog, options);
    var onKeyDownRef = useLiveRef(htmlOnKeyDown);
    var onBlurRef = useLiveRef(htmlOnBlur);
    var focusOnBlur = useFocusOnBlur(dialog, options);
    var {
      dialogs,
      visibleModals,
      wrap
    } = useNestedDialogs(dialog, options); // VoiceOver/Safari accepts only one `aria-modal` container, so if there
    // are visible child modals, then we don't want to set aria-modal on the
    // parent modal (this component).

    var modal = optionsModal && !visibleModals.length ? true : undefined;
    useFocusTrap(dialog, visibleModals, options);
    useFocusOnChildUnmount(dialog, options);
    useFocusOnShow(dialog, dialogs, options);
    useFocusOnHide(dialog, disclosure, options);
    useHideOnClickOutside(dialog, disclosure, dialogs, options);
    useDisableHoverOutside(dialog, dialogs, options);
    var onKeyDown = React.useCallback(event => {
      var _onKeyDownRef$current;

      (_onKeyDownRef$current = onKeyDownRef.current) === null || _onKeyDownRef$current === void 0 ? void 0 : _onKeyDownRef$current.call(onKeyDownRef, event);
      if (event.defaultPrevented) return;
      if (event.key !== "Escape") return;
      if (!hideOnEsc) return;

      if (!hide) {
        warning(true, "`hideOnEsc` prop is truthy, but `hide` prop wasn't provided.", dialog.current);
        return;
      }

      event.stopPropagation();
      hide();
    }, [onKeyDownRef, hideOnEsc, hide]);
    var onBlur = React.useCallback(event => {
      var _onBlurRef$current;

      (_onBlurRef$current = onBlurRef.current) === null || _onBlurRef$current === void 0 ? void 0 : _onBlurRef$current.call(onBlurRef, event);
      focusOnBlur(event);
    }, [focusOnBlur, onBlurRef]);
    var wrapElement = React.useCallback(element => {
      element = wrap(element);

      if (optionsModal && !hasBackdrop) {
        if (preventBodyScroll) {
          element = /*#__PURE__*/_jsx(Portal, {
            children: /*#__PURE__*/_jsx(RemoveScroll, {
              children: element
            })
          });
        } else {
          element = /*#__PURE__*/_jsx(Portal, {
            children: element
          });
        }
      }

      if (htmlWrapElement) {
        element = htmlWrapElement(element);
      } // return (
      //   // Prevents Menu > Dialog > Menu to behave as a sub menu
      //   <MenuContext.Provider value={null}>{element}</MenuContext.Provider>
      // );


      return element;
    }, [wrap, optionsModal, hasBackdrop, htmlWrapElement, preventBodyScroll]);
    return _objectSpread({
      ref: useForkRef(dialog, htmlRef),
      role: "dialog",
      tabIndex: tabIndex !== null && tabIndex !== void 0 ? tabIndex : -1,
      "aria-modal": modal,
      "data-dialog": true,
      onKeyDown,
      onBlur,
      wrapElement
    }, restHtmlProps);
  }

});
export var Dialog = createComponent({
  as: "div",
  useHook: useDialog,
  useCreateElement: (type, props, children) => {
    useWarning(!props["aria-label"] && !props["aria-labelledby"], "You should provide either `aria-label` or `aria-labelledby` props.");
    return _useCreateElement(type, props, children);
  }
});
//# sourceMappingURL=Dialog.js.map