import * as React from "react";
import { contains, getDocument, useLiveRef } from "reakit-utils";
import { warning } from "reakit-warning";
import { isFocusTrap } from "./useFocusTrap";

function dialogContains(target) {
  return dialogRef => {
    var dialog = dialogRef.current;
    if (!dialog) return false;
    if (contains(dialog, target)) return true;
    var document = getDocument(dialog);
    var backdrop = document.querySelector("[data-dialog-ref=\"".concat(dialog.id, "\"]"));

    if (backdrop) {
      return contains(backdrop, target);
    }

    return false;
  };
}

function isDisclosure(target, disclosure) {
  return contains(disclosure, target);
}

function isInDocument(target) {
  var document = getDocument(target);

  if (target.tagName === "HTML") {
    return true;
  }

  return contains(document.body, target);
}

export function useEventListenerOutside(containerRef, disclosureRef, nestedDialogs, eventType, listener, shouldListen, capture) {
  var listenerRef = useLiveRef(listener);
  React.useEffect(() => {
    if (!shouldListen) return undefined;

    var onEvent = event => {
      if (!listenerRef.current) return;
      var container = containerRef.current;
      var disclosure = disclosureRef.current;
      var target = event.target;

      if (!container) {
        warning(true, "Can't detect events outside dialog because `ref` wasn't passed to component.");
        return;
      } // When an element is unmounted right after it receives focus, the focus
      // event is triggered after that, when the element isn't part of the
      // current document anymore. So we ignore it.


      if (!isInDocument(target)) return; // Event inside dialog

      if (contains(container, target)) return; // Event on disclosure

      if (disclosure && isDisclosure(target, disclosure)) return; // Event inside a nested dialog or focus trap

      if (isFocusTrap(target) || nestedDialogs.some(dialogContains(target))) {
        return;
      }

      listenerRef.current(event);
    };

    var document = getDocument(containerRef.current);
    document.addEventListener(eventType, onEvent, capture);
    return () => document.removeEventListener(eventType, onEvent, capture);
  }, [containerRef, disclosureRef, nestedDialogs, eventType, shouldListen, listenerRef, capture]);
}
//# sourceMappingURL=useEventListenerOutside.js.map