function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

import React from "react";
import { fireEvent, render } from "reakit-test-utils";
import { axe } from "jest-axe";
import { announce, destroyAnnouncer, LiveRegionAnnouncer } from "./LiveAnnouncer";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
beforeEach(() => {
  destroyAnnouncer();
});
describe("LiveAnnouncer", () => {
  it("should render correctly", () => {
    announce("Hello world", "assertive", 0);
    expect(document.body).toMatchSnapshot();
    destroyAnnouncer();
    expect(document.body).toMatchInlineSnapshot("<body />");
  });
  test("LiveRegionAnnouncer", () => {
    var assertiveMessage = "Hello Assertive";
    var politeMessage = "Hello Polite";

    var Announcer = () => {
      var ref = React.useRef();
      return /*#__PURE__*/_jsxs("div", {
        children: [/*#__PURE__*/_jsx(LiveRegionAnnouncer, {
          ref: ref
        }), /*#__PURE__*/_jsx("button", {
          onClick: () => ref.current.announce(assertiveMessage, "assertive", 0),
          children: "announce assertive"
        }), /*#__PURE__*/_jsx("button", {
          onClick: () => ref.current.announce(politeMessage, "polite", 0),
          children: "announce polite"
        }), /*#__PURE__*/_jsx("button", {
          onClick: () => ref.current.clear(),
          children: "clear"
        })]
      });
    };

    var {
      getByText: text,
      queryAllByTestId: testIdAll
    } = render( /*#__PURE__*/_jsx(Announcer, {}));
    fireEvent.click(text("announce assertive"));
    expect(testIdAll("announcer-assertive")[1]).toHaveTextContent(assertiveMessage); // Clear

    fireEvent.click(text("clear"));
    expect(testIdAll("announcer-assertive")[1]).toHaveTextContent(""); // Polite

    fireEvent.click(text("announce polite"));
    expect(testIdAll("announcer-polite")[1]).toHaveTextContent(politeMessage); // Clear

    fireEvent.click(text("clear"));
    expect(testIdAll("announcer-polite")[1]).toHaveTextContent("");
  });
  test("LiveAnnouncer renders with no a11y violations", /*#__PURE__*/_asyncToGenerator(function* () {
    announce("Hello a11y");
    var results = yield axe(document.body);
    expect(results).toHaveNoViolations();
  }));
});
//# sourceMappingURL=LiveAnnouncer.test.js.map