import { Dispatch, SetStateAction } from "react";
import { AccordionBaseActions, AccordionBaseInitialState, AccordionBaseState } from "./AccordionBaseState";
export declare function useAccordionMultiState(props?: AccordionMultiInitialState): AccordionMultiStateReturn;
export declare type AccordionMultiState = AccordionBaseState & {
    /**
     * The current selected accordion's `id`.
     */
    selectedIds: string[];
    /**
     * Allow to toggle accordion items
     * @default false
     */
    allowToggle: boolean;
    /**
     * Allow to open multiple accordion items
     */
    allowMultiple: boolean;
    /**
     * Whether the accodion selection should be manual.
     * @default true
     */
    manual: boolean;
};
export declare type AccordionMultiActions = AccordionBaseActions & {
    /**
     * Sets the value.
     */
    setSelectedIds: Dispatch<SetStateAction<string[]>>;
    /**
     * Moves into and selects an accordion by its `id`.
     */
    select: (id: string) => void;
};
export declare type AccordionMultiInitialState = Pick<Partial<AccordionMultiState>, "manual" | "selectedIds"> & {
    /**
     * The initial value to be used, in uncontrolled mode
     * @default []
     */
    defaultSelectedIds?: string[] | (() => string[]);
    /**
     * The callback fired when the value changes
     */
    onSelectedIdsChange?: (value: string[]) => void;
    /**
     * The function that determines if the state should be updated
     */
    shouldUpdate?: (prev: string[], next: string[]) => boolean;
} & AccordionBaseInitialState;
export declare type AccordionMultiStateReturn = AccordionMultiState & AccordionMultiActions;
