import { Dispatch, SetStateAction } from "react";
import { AccordionBaseActions, AccordionBaseInitialState, AccordionBaseState } from "./AccordionBaseState";
import { StringOrNull } from "./helpers";
export declare function useAccordionState(props?: AccordionInitialState): AccordionStateReturn;
export declare type AccordionState = AccordionBaseState & {
    /**
     * The current selected accordion's `id`.
     */
    selectedId: StringOrNull;
    /**
     * Allow to toggle accordion items
     * @default false
     */
    allowToggle: boolean;
    /**
     * Allow to open multiple accordion items
     */
    allowMultiple: boolean;
    /**
     * Whether the accodion selection should be manual.
     * @default true
     */
    manual: boolean;
};
export declare type AccordionActions = AccordionBaseActions & {
    /**
     * Sets the value.
     */
    setSelectedId: Dispatch<SetStateAction<StringOrNull>>;
    /**
     * Moves into and selects an accordion by its `id`.
     */
    select: (id: string) => void;
};
export declare type AccordionInitialState = Pick<Partial<AccordionState>, "manual" | "allowToggle" | "selectedId"> & {
    /**
     * The initial value to be used, in uncontrolled mode
     * @default null
     */
    defaultSelectedId?: StringOrNull | (() => StringOrNull);
    /**
     * The callback fired when the value changes
     */
    onSelectedIdChange?: (value: StringOrNull) => void;
    /**
     * The function that determines if the state should be updated
     */
    shouldUpdate?: (prev: StringOrNull, next: StringOrNull) => boolean;
} & AccordionBaseInitialState;
export declare type AccordionStateReturn = AccordionState & AccordionActions;
